"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const crc32_1 = require("@node-rs/crc32");
const events_1 = require("events");
/**
 * Converts given string to Buffer, using ascii encoding if string is ASCII only
 * Returns Buffer as is
 *
 * @param {string | Buffer} data
 */
async function dataToBuffer(data) {
    if (Buffer.isBuffer(data)) {
        return {
            bytes: data,
            crc32: crc32_1.crc32(data),
        };
    }
    if (typeof data === 'string') {
        return dataToBuffer.call(this, 
        // we will use ASCII encoding if string is ascii only, saving some bytes
        Buffer.from(data, /^[\p{ASCII}]+$/u.test(data) ? 'ascii' : 'utf-8'));
    }
    // convert stream to buffer
    const res = [];
    data
        .on('data', chunk => {
        const buf = Buffer.isBuffer(chunk) ? chunk : Buffer.from(chunk, 'utf-8');
        res.push(buf);
        // as our crc32 calculation is using native extension it's faster to calculate it once on whole buffer
        // crc += crc32c(buf, crc);
    })
        .on('error', err => {
        // re-emit error as upstream
        this.emit('error', err);
    });
    await events_1.once(data, 'end');
    const bytes = Buffer.concat(res);
    return { bytes, crc32: crc32_1.crc32(bytes) };
}
exports.dataToBuffer = dataToBuffer;
//# sourceMappingURL=data-to-bytes.js.map